@@ -26,7 +26,6 @@ extensions = [
     "sphinx.ext.napoleon",
     "sphinx.ext.todo",
     "sphinx.ext.viewcode",
-    "sphinx_click",
     "sphinx_copybutton",
     "sphinx_json_schema_spec",
     "sphinxcontrib.spelling",
@@ -119,6 +118,11 @@ extlinks = {
 }
 extlinks_detect_hardcoded_links = True
 
+# -- sphinx-copybutton --
+
+copybutton_prompt_text = r">>> |\.\.\. |\$"
+copybutton_prompt_is_regexp = True
+
 # -- sphinxcontrib-spelling --
 
 spelling_word_list_filename = "spelling-wordlist.txt"
